Array

Struct Array 

pub struct Array {
    pub objects: Vec<Value>,
    /* private fields */
}
An Array is an ordered sequence of Value objects which must all be of the same variety. That is, it is not value to have a Uint8 and a Uint32 as elements of the same Array.

Fields

objects: Vec<Value>

Implementations

Source

impl Array

pub fn new(objects: Vec<Value>) -> Array

Create a new array from the given vector of Value. This function may only be used when it is never possible for the input vector to be empty. The reason is that it is impossible to determine the type signature for an empty vector. Use new_with_sig instead.

Panics

If objects.len() is 0, this function will panic.

pub fn new_with_sig(objects: Vec<Value>, sig: String) -> Array

Create a new array from the given vector. If sig is not of the form a or if objects is non-empty and the inner type does not match the type of the contents, the resulting value will be invalid and will not encode correctly.