pub struct Variant {
pub object: Box<Value>,
pub signature: Signature,
}Expand description
A Variant is a boxed type-erased value. It is trasmitted on the wire with its signature. It is useful for arrays with varying types and for allowing DBus method argument types to be determined at runtime. signature contains the signature of the boxed value.
Fields
object: Box<Value>signature: SignatureImplementations