Module types

Module types 

Contains the Value and BasicValue enums, as well as traits and helper types for them

Structs

Array
An Array is an ordered sequence of Value objects which must all be of the same variety. That is, it is not value to have a Uint8 and a Uint32 as elements of the same Array.
Dictionary
Path
Signature
Struct
A Struct is an ordered sequence of Value objects, which may be of different varieties. signature must be of the form “()”, where is the signature of contents of objects.
Variant
A Variant is a boxed type-erased value. It is trasmitted on the wire with its signature. It is useful for arrays with varying types and for allowing DBus method argument types to be determined at runtime. signature contains the signature of the boxed value.

Enums

BasicValue
BasicValue covers the “basic” D-Bus types, that is those that are allowed to be used as keys in a dictionary.
Value
Root type for any D-Bus value