pub struct Array {
pub objects: Vec<Value>,
/* private fields */
}Expand description
An Array is an ordered sequence of Value objects which must all be of the same variety. That is, it is not value to have a Uint8 and a Uint32 as elements of the same Array.
Fields
objects: Vec<Value>Implementations
Sourceimpl Array
impl Array
Sourcepub fn new(objects: Vec<Value>) -> Array
pub fn new(objects: Vec<Value>) -> Array
Create a new array from the given vector of Value. This function may only be used when it is never possible for the input vector to be empty. The reason is that it is impossible to determine the type signature for an empty vector. Use new_with_sig instead.
Panics
If objects.len() is 0, this function will panic.