Dictionary

Struct Dictionary 

pub struct Dictionary {
    pub map: HashMap<BasicValue, Value>,
    /* private fields */
}

Fields

map: HashMap<BasicValue, Value>

Implementations

Source

impl Dictionary

pub fn new(map: HashMap<BasicValue, Value>) -> Dictionary

Create a new Dictionary from the given map. This function may only be used when it is never possible for the input map to be empty. The reason is that it is impossible to determine the type signature for an empty vector. Use new_with_sig instead.

Panics

If map.len() is 0, this function will panic.

pub fn new_with_sig(map: HashMap<BasicValue, Value>, sig: String) -> Dictionary

Create a new Dictionary from the given map. If sig is not of the form a{} or if map is non-empty and the inner types do not match the type of the map’s contents, the resulting value will be invalid and will not encode correctly.